VAUL3T is an open source project dedicated to developing OSINT tools. We provide full access to the source code to support bug hunting and to demonstrate our strict zero knowledge policy.

We guarantee that we do not collect any data that can be linked back to you.

Only in rare cases such as when enabling anti–rate limiting features we may require your Telegram username.

Please note: All our projects are licensed under (GPLv3)

We are not responsible for any damange done by modified versions, We only offer support and guarantee for our ORIGINAL service.


More info can be found on https://github.com/VAUL3T/PyPI
